==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/ROUTEEQUIPMENTTYPE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ROUTEEQUIPMENTTYPE_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ROUTEEQUIPMENTTYPE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBJTYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBJRTYPE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ROUTEEQUIPMENTTYPE_Type", propOrder = {
    "equipmentid",
    "objtype",
    "objrtype"
})
public class ROUTEEQUIPMENTTYPE_Type {

    @XmlElement(name = "EQUIPMENTID", required = true)
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "OBJTYPE")
    protected String objtype;
    @XmlElement(name = "OBJRTYPE")
    protected String objrtype;

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Gets the value of the objtype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOBJTYPE() {
        return objtype;
    }

    /**
     * Sets the value of the objtype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOBJTYPE(String value) {
        this.objtype = value;
    }

    /**
     * Gets the value of the objrtype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOBJRTYPE() {
        return objrtype;
    }

    /**
     * Sets the value of the objrtype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOBJRTYPE(String value) {
        this.objrtype = value;
    }

}

==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/ROUTEEQUIPMENTTYPE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ROUTEEQUIPMENTTYPE_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ROUTEEQUIPMENTTYPE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBJTYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBJRTYPE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ROUTEEQUIPMENTTYPE_Type", propOrder = {
    "equipmentid",
    "objtype",
    "objrtype"
})
public class ROUTEEQUIPMENTTYPE_Type {

    @XmlElement(name = "EQUIPMENTID", required = true)
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "OBJTYPE")
    protected String objtype;
    @XmlElement(name = "OBJRTYPE")
    protected String objrtype;

    /**
     * Obtient la valeur de la propriété equipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Définit la valeur de la propriété equipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété objtype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOBJTYPE() {
        return objtype;
    }

    /**
     * Définit la valeur de la propriété objtype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOBJTYPE(String value) {
        this.objtype = value;
    }

    /**
     * Obtient la valeur de la propriété objrtype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOBJRTYPE() {
        return objrtype;
    }

    /**
     * Définit la valeur de la propriété objrtype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOBJRTYPE(String value) {
        this.objrtype = value;
    }

}
